import tkinter as tk
from tkinter import font  as tkfont
from tkinter import filedialog
from tkinter import ttk
from tkinter import *
from zebrazoom.code.vars import getGlobalVariables
globalVariables = getGlobalVariables()


class CreateExperimentOrganizationExcel(tk.Frame):

  def __init__(self, parent, controller):
  
    tk.Frame.__init__(self, parent)
    self.controller = controller
    label = tk.Label(self, text="Prepare experiment organization excel file:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    tk.Label(self, text="").pack()
    tk.Label(self, text="To further analyze the outputs of ZebraZoom you must create an excel file to describe how you organized your experiments.").pack()
    tk.Label(self, text="Click on the button below to open the folder where you should store that excel file.").pack()
    tk.Label(self, text="In this folder you will also find an file named 'example' showing an example of such an excel file.").pack()
    tk.Label(self, text="In these excel files, set the columns as explained below:").pack()
    tk.Label(self, text="If you haven't moved the output folders of ZebraZoom, leave defaultZZoutputFolder as the value for path.").pack()
    tk.Label(self, text="fq needs to be set to the frequency of acquisition of your video and pixelSize needs to be set to the number microns in each pixel of your video.").pack()
    tk.Label(self, text="condition and genotype need to be set to arrays for which each element represents a well and is set the condition/genotype of that well.").pack()
    tk.Label(self, text="include is an array for which each element is set to 1 if the corresponding well should be included in the analysis and 0 otherwise.").pack()
    tk.Label(self, text="").pack()
    
    tk.Button(self, text="Open experiment organization excel files folder", command=lambda: controller.openExperimentOrganizationExcelFolder(controller.homeDirectory)).pack()
    
    tk.Label(self, text="").pack()
    tk.Label(self, text="You have to create an excel file describing the organization of your experiment and you should place it inside the folder opened with the button above.").pack()
    tk.Label(self, text="Once this is done, click on the button below:").pack()
    tk.Label(self, text="").pack()
    
    tk.Button(self, text="Ok done!", bg="light yellow", command=lambda: controller.show_frame("ChooseExperimentOrganizationExcel")).pack()
    
    tk.Label(self, text="").pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()


class ChooseExperimentOrganizationExcel(tk.Frame):

  def __init__(self, parent, controller):
  
    tk.Frame.__init__(self, parent)
    self.controller = controller
    label = tk.Label(self, text="Choose organization excel file:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    tk.Button(self, text="Select the excel file describing the organization of your experiment.", bg="light yellow", command=lambda: controller.chooseExperimentOrganizationExcel(controller)).pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()


class ChooseDataAnalysisMethod(tk.Frame):

  def __init__(self, parent, controller):
  
    tk.Frame.__init__(self, parent)
    self.controller = controller
    label = tk.Label(self, text="Choose the analysis you want to perform:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    tk.Button(self, text="Compare populations with kinematic parameters", bg="light yellow", command=lambda: controller.show_frame("PopulationComparison")).pack()
    tk.Button(self, text="Cluster bouts of movements  (for zebrafish only)", bg="light yellow", command=lambda: controller.show_frame("BoutClustering")).pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()


class PopulationComparison(tk.Frame):

  def __init__(self, parent, controller):
  
    tk.Frame.__init__(self, parent)
    self.controller = controller
    label = tk.Label(self, text="Population Comparison:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    BoutDuration = IntVar()
    Checkbutton(self, text="BoutDuration", variable=BoutDuration).pack()
    TotalDistance = IntVar()
    Checkbutton(self, text="TotalDistance", variable=TotalDistance).pack()
    Speed = IntVar()
    Checkbutton(self, text="Speed", variable=Speed).pack()
    NumberOfOscillations = IntVar()
    Checkbutton(self, text="NumberOfOscillations (for zebrafish only)", variable=NumberOfOscillations).pack()
    meanTBF = IntVar()
    Checkbutton(self, text="meanTBF (for zebrafish only)", variable=meanTBF).pack()
    maxAmplitude = IntVar()
    Checkbutton(self, text="maxAmplitude (for zebrafish only)", variable=maxAmplitude).pack()
    
    tk.Label(self, text="", font=("Helvetica", 10)).pack(side="top", fill="x", pady=10)
    tk.Label(self, text="If you are calculating one these three parameters: NumberOfOscillations, meanTBF, maxAmplitude:", font="bold").pack(side="top", fill="x")
    tk.Label(self, text="What's the minimum number of bends a bout should have to be taken into account for the analysis?", font=("Helvetica", 10)).pack(side="top", fill="x")
    tk.Label(self, text="(the default value is 3) (put 0 if you want all bends to be taken into account)", font=("Helvetica", 10)).pack(side="top", fill="x")
    minNbBendForBoutDetect = tk.Entry(self)
    minNbBendForBoutDetect.pack()
    tk.Label(self, text="If, for a bout, NumberOfOscillations, meanTBF and maxAmplitude are being discarded because of a low amount of bends,?", font=("Helvetica", 10)).pack(side="top", fill="x")
    tk.Label(self, text="should the BoutDuration, TotalDistance and Speed also be discarded for that bout?", font=("Helvetica", 10)).pack(side="top", fill="x")
    discard = IntVar()
    Checkbutton(self, text="Yes, discard BoutDuration, TotalDistance and Speed in that situation", variable=discard).pack()
    keep = IntVar()
    Checkbutton(self, text="No, keep BoutDuration, TotalDistance and Speed in that situation", variable=keep).pack()
    tk.Label(self, text="Please ignore the two questions above if you're only looking at BoutDuration, TotalDistance and Speed.", font=("Helvetica", 10)).pack(side="top", fill="x", pady=10)
    
    tk.Button(self, text="Launch Analysis", bg="light yellow", command=lambda: controller.populationComparison(controller, BoutDuration.get(), TotalDistance.get(), Speed.get(), NumberOfOscillations.get(), meanTBF.get(), maxAmplitude.get(), minNbBendForBoutDetect.get(), discard.get(), keep.get())).pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()


class BoutClustering(tk.Frame):

  def __init__(self, parent, controller):
  
    tk.Frame.__init__(self, parent)
    self.controller = controller
    
    label = tk.Label(self, text="Bout Clustering:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    tk.Label(self, text="Choose number of cluster to find:").pack()
    nbClustersToFind = tk.Entry(self)
    nbClustersToFind.pack()
    
    tk.Label(self, text="Choose one of the options below:").pack()
    FreelySwimming = IntVar()
    Checkbutton(self, text="Freely swimming fish with tail tracking", variable=FreelySwimming).pack()
    HeadEmbeded = IntVar()
    Checkbutton(self, text="Head embeded fish with tail tracking", variable=HeadEmbeded).pack()
    
    tk.Button(self, text="Launch Analysis", bg="light yellow", command=lambda: controller.boutClustering(controller, nbClustersToFind.get(), FreelySwimming.get(), HeadEmbeded.get())).pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()


class AnalysisOutputFolderPopulation(tk.Frame):

  def __init__(self, parent, controller):
    
    tk.Frame.__init__(self, parent)
    self.controller = controller
    label = tk.Label(self, text="View Analysis Output:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    tk.Label(self, text="").pack()
    tk.Label(self, text="Click the button below to open the folder that contains the results of the analysis.").pack()
    tk.Label(self, text="").pack()
    
    tk.Button(self, text="View results folder", bg="light yellow", command=lambda: controller.openPopulationAnalysisFolder(controller.homeDirectory)).pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()


class AnalysisOutputFolderClustering(tk.Frame):

  def __init__(self, parent, controller):
    
    tk.Frame.__init__(self, parent)
    self.controller = controller
    label = tk.Label(self, text="View Analysis Output:", font=controller.title_font)
    label.pack(side="top", fill="x", pady=10)
    
    tk.Label(self, text="").pack()
    tk.Label(self, text="Click the button below to open the folder that contains the results of the analysis.").pack()
    tk.Label(self, text="").pack()
    
    tk.Button(self, text="View results folder", bg="light yellow", command=lambda: controller.openClusteringAnalysisFolder(controller.homeDirectory)).pack()
    
    tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()




import json
import numpy as np
import pandas as pd
import os
import time
import datetime

def calculateSleepVsMovingPeriods(pathToZZoutput, vidName, speedThresholdForMoving, notMovingNumberOfFramesThresholdForSleep, distanceTravelledRollingMedianFilter=0, videoPixelSize=-1, videoFPS=-1):
  
  videoNamelist    = []
  dfFinalAllVideos = pd.DataFrame()
  currentNbFrames  = 0
  
  if ',' in vidName:
    videoNamelist = vidName.split(',')
  else:
    videoNamelist = [vidName]
  
  for videoName in videoNamelist:
  
    pathToVideo = os.path.join(pathToZZoutput, videoName, "results_" + videoName + ".txt")
    
    with open(pathToVideo) as ff:
      dataRef = json.load(ff)
    
    if videoPixelSize == -1:
      if "videoPixelSize" in dataRef:
        videoPixelSize = dataRef["videoPixelSize"]
      else:
        print("You should add the parameter 'videoPixelSize' in your configuration file")
        videoPixelSize = 1
    
    if videoFPS == -1:
      if "videoFPS" in dataRef:
        videoFPS = dataRef["videoFPS"]
      else:
        print("You should add the parameter 'videoFPS' in your configuration file")
        videoFPS = 1
    
    dfFinal = pd.DataFrame()
    totalFrames  = len(dataRef['wellPoissMouv'][0][0][0]["HeadX"])
    times = [time.strftime('%H:%M:%S', time.gmtime(second)) for second in [(i + currentNbFrames) / videoFPS for i in range(0, totalFrames + 1)]]
    currentNbFrames = currentNbFrames + totalFrames + 1
    df = pd.DataFrame(data = np.transpose([times]), columns = ['HourMinuteSecond'])
    dfFinal = pd.concat([dfFinal, df], axis=1)
    
    for wellNumber in range(len(dataRef['wellPoissMouv'])):
      
      displacementVector = videoPixelSize * np.diff(np.array([dataRef['wellPoissMouv'][wellNumber][0][0]["HeadX"], dataRef['wellPoissMouv'][wellNumber][0][0]["HeadY"]]))
      squaredDisplacement = displacementVector * displacementVector
      distance = np.sqrt(squaredDisplacement[0] + squaredDisplacement[1])
      # distance = np.append(distance, [0])
      distance = np.insert(distance, 0, 0)
      distance = np.insert(distance, 0, 0)
      if distanceTravelledRollingMedianFilter:
        distance2 = np.convolve(distance, np.ones(distanceTravelledRollingMedianFilter), 'same') / distanceTravelledRollingMedianFilter
        distance2[:distanceTravelledRollingMedianFilter-1] = distance[:distanceTravelledRollingMedianFilter-1]
        distance2[-distanceTravelledRollingMedianFilter+1:] = distance[-distanceTravelledRollingMedianFilter+1:]
        distance = distance2
      
      speed = distance * videoFPS
      
      moving = speed > speedThresholdForMoving
      
      sleep = np.array([False for i in range(len(moving))])
      countNotMovingFrames = 0
      for i in range(len(sleep)):
        if moving[i]:
          countNotMovingFrames = 0
        else:
          countNotMovingFrames = countNotMovingFrames + 1
          if countNotMovingFrames >= notMovingNumberOfFramesThresholdForSleep:
            sleep[i] = True
          if countNotMovingFrames == notMovingNumberOfFramesThresholdForSleep:
            countNotMovingFrames2 = countNotMovingFrames - 1
            j = i - 1
            while j >= 0 and countNotMovingFrames2 > 0:
              sleep[j] = True
              countNotMovingFrames2 = countNotMovingFrames2 - 1
              j = j - 1
      
      df = pd.DataFrame(data = np.transpose(np.append(np.append([speed], [moving], axis=0), [sleep], axis=0)), columns = ['speed_' + str(wellNumber), 'moving_' + str(wellNumber), 'sleep_' + str(wellNumber)])
      dfFinal = pd.concat([dfFinal, df], axis=1)
    
    dfFinal.to_excel(os.path.join(pathToZZoutput, videoName, "sleepVsMoving_" + videoName + ".xlsx"))
    dfFinalAllVideos = pd.concat([dfFinalAllVideos, dfFinal], axis=0)
    
    
  if len(videoNamelist) > 1:
    
    concatExcelFileName = "".join(videoNamelist)
    dfFinalAllVideos.to_excel(os.path.join(pathToZZoutput, "sleepVsMoving_" + concatExcelFileName + ".xlsx"))

def firstSleepingTimeAfterSpecifiedTime(pathToZZoutput, vidName, specifiedTime, wellNumber):
  
  videoNamelist    = []
  if ',' in vidName:
    concatExcelFileName = "".join(vidName.split(','))
    df = pd.read_excel(os.path.join(pathToZZoutput, "sleepVsMoving_" + concatExcelFileName + ".xlsx"))
  else:
    df = pd.read_excel(os.path.join(os.path.join(pathToZZoutput, vidName), "sleepVsMoving_" + vidName + ".xlsx"))
  
  dfTimeMinusSpecifiedTime = (df['HourMinuteSecond'].apply(datetime.datetime.strptime, args=("%H:%M:%S",)) - datetime.datetime.strptime(specifiedTime, "%H:%M:%S")).apply(pd.Timedelta.total_seconds).apply(abs)
  indexStart = dfTimeMinusSpecifiedTime.argmin()
  dfLength = len(df)
  currentIndex = indexStart
  while (currentIndex != dfLength) and (df['sleep_' + wellNumber][currentIndex] == 0):
    currentIndex = currentIndex + 1
  if currentIndex == dfLength:
    print("For the well number", wellNumber, ", couldn't find any time point after", specifiedTime, "for which the fish was sleeping")
  else:
    print("For the well number:", wellNumber, "and the specified time:", specifiedTime, ".")
    print("The first time after the specified time when the fish starts sleeping is at", df['HourMinuteSecond'][currentIndex], "(which corresponds to frame number:", currentIndex, ").")
    print("In other words, the fish starts sleeping", dfTimeMinusSpecifiedTime[currentIndex], "seconds after the specified time (or", currentIndex - indexStart, "frames after the specified time) (or", time.strftime('%H:%M:%S', time.gmtime(dfTimeMinusSpecifiedTime[currentIndex])), "Hours:Minutes:Seconds after the specified time)")



if __name__ == '__main__':

  import sys
  import os
  dir_path = os.path.dirname(os.path.realpath(__file__))

  from zebrazoom.code.vars import getGlobalVariables
  globalVariables = getGlobalVariables()

  if len(sys.argv) == 1:
    
    print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
    from zebrazoom.GUIAllPy import SampleApp
    app = SampleApp()
    app.mainloop()
      
  else:

    if sys.argv[1] == "getTailExtremityFirstFrame":
      
      pathToVideo = sys.argv[2]
      videoName   = sys.argv[3]
      videoExt    = sys.argv[4]
      configFile  = sys.argv[5]
      argv        = sys.argv
      argv.pop(0)
      from zebrazoom.getTailExtremityFirstFrame import getTailExtremityFirstFrame
      __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
      getTailExtremityFirstFrame(pathToVideo, videoName, videoExt, configFile, argv)
        
    elif sys.argv[1] == "recreateSuperStruct":
      
      pathToVideo = sys.argv[2]
      videoName   = sys.argv[3]
      videoExt    = sys.argv[4]
      configFile  = sys.argv[5]
      argv        = sys.argv
      argv.pop(0)
      from zebrazoom.recreateSuperStruct import recreateSuperStruct
      __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
      recreateSuperStruct(pathToVideo, videoName, videoExt, configFile, argv)
        
    elif sys.argv[1] == "convertSeqToAvi":
      
      from zebrazoom.videoFormatConversion.seq_to_avi import sqb_convert_to_avi
      path      = sys.argv[2]
      videoName = sys.argv[3]
      if len(sys.argv) == 5:
        lastFrame = int(sys.argv[4])
      else:
        lastFrame = -1
      sqb_convert_to_avi(path, videoName, lastFrame)

    elif sys.argv[1] == "dataPostProcessing":
      
      if sys.argv[2] == "sleepVsMoving":
        from zebrazoom.code.dataPostProcessing.findSleepVsMoving import calculateSleepVsMovingPeriods
        pathToZZoutput = os.path.join(dir_path,'ZZoutput')
        videoName      = sys.argv[3]
        speedThresholdForMoving = float(sys.argv[4])
        notMovingNumberOfFramesThresholdForSleep = int(sys.argv[5])
        if len(sys.argv) >= 7:
          distanceTravelledRollingMedianFilter = int(sys.argv[6])
        else:
          distanceTravelledRollingMedianFilter = 0
        if len(sys.argv) >= 9:
          videoPixelSize = float(sys.argv[7])
          videoFPS = float(sys.argv[8])
        else:
          videoPixelSize = -1
          videoFPS = -1
        calculateSleepVsMovingPeriods(pathToZZoutput, videoName, speedThresholdForMoving, notMovingNumberOfFramesThresholdForSleep, distanceTravelledRollingMedianFilter, videoPixelSize, videoFPS)
      
      if sys.argv[2] == "firstSleepingTimeAfterSpecifiedTime":
        from zebrazoom.code.dataPostProcessing.findSleepVsMoving import firstSleepingTimeAfterSpecifiedTime
        pathToZZoutput = os.path.join(dir_path,'ZZoutput')
        videoName      = sys.argv[3]
        specifiedTime  = sys.argv[4]
        wellNumber     = sys.argv[5]
        firstSleepingTimeAfterSpecifiedTime(pathToZZoutput, videoName, specifiedTime, wellNumber)
        
      if sys.argv[2] == "calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshod":
        from zebrazoom.dataAnalysis.postProcessingFromCommandLine.postProcessingFromCommandLine import calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold
        calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold(dir_path, sys.argv[3], int(sys.argv[4]))
        
    elif sys.argv[1] == "visualizeMovingAndSleepingTime":
      
      from zebrazoom.code.readValidationVideo import readValidationVideo
      import pandas as pd
      df = pd.read_excel(os.path.join(os.path.join(os.path.join(dir_path, 'ZZoutput'), sys.argv[3]), "sleepVsMoving_" + sys.argv[3] + ".xlsx"))
      nbWells = int(len(df.columns)/3)
      
      if sys.argv[2] == "movingTime":
        
        framesToShow = df[["moving_" + str(i) for i in range(0, nbWells)]].to_numpy()
        readValidationVideo("", sys.argv[3], "", -1, -1, 0, 1, framesToShow)
        
      elif sys.argv[2] == "sleepingTime":
        
        framesToShow = df[["sleep_" + str(i) for i in range(0, nbWells)]].to_numpy()
        readValidationVideo("", sys.argv[3], "", -1, -1, 0, 1, framesToShow)
        
    else:
      
      print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
      pathToVideo = sys.argv[1]
      videoName   = sys.argv[2]
      videoExt    = sys.argv[3]
      configFile  = sys.argv[4]
      argv        = sys.argv
      from zebrazoom.mainZZ import mainZZ
      __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
      mainZZ(pathToVideo, videoName, videoExt, configFile, argv)



import os
import math
import shutil
import matplotlib.pyplot as plt
import pickle
import numpy as np

def populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, outputFolder):

  outputFolderResult = os.path.join(outputFolder, nameOfFile)

  if os.path.exists(outputFolderResult):
    shutil.rmtree(outputFolderResult)
  os.mkdir(outputFolderResult)

  infile = open(os.path.join(resFolder, nameOfFile),'rb')
  dfParam = pickle.load(infile)
  infile.close()
  
  columnsForRawDataExport = ['index', 'Trial_ID', 'Well_ID', 'NumBout', 'BoutStart', 'BoutEnd', 'Condition', 'Genotype'] + globParam
  dfParam[columnsForRawDataExport].to_excel(os.path.join(outputFolderResult, 'globalParametersInsideCategories.xlsx'))
  
  nbLines   = int(math.sqrt(len(globParam)))
  nbColumns = math.ceil(len(globParam) / nbLines)
  fig, tabAx = plt.subplots(nbLines, nbColumns, figsize=(22.9, 8.8))
  for idx, parameter in enumerate(globParam):
    concatenatedValues = []
    labels = []
    for condition in conditions:
      for genotype in genotypes:
        indicesCondition = dfParam.index[dfParam['Condition'] == condition].tolist()
        indicesGenotype  = dfParam.index[dfParam['Genotype']  == genotype].tolist()
        indices = [ind for ind in indicesCondition if ind in indicesGenotype] 
        values  = dfParam.loc[indices, parameter].values
        concatenatedValues.append(values)
        labels.append(str(condition) + '\n' + str(genotype))
    
    concatenatedValuesWithoutNans = []
    for toConcat in concatenatedValues:
      concatenatedValuesWithoutNans.append(np.array([x for x in toConcat if not(math.isnan(x))]))
    concatenatedValues = concatenatedValuesWithoutNans
    
    if nbLines == 1:
      tabAx[idx%nbColumns].set_title(parameter)
      tabAx[idx%nbColumns].boxplot(concatenatedValues)
      tabAx[idx%nbColumns].set_xticklabels(labels)    
    else:
      tabAx[int(idx/nbColumns), idx%nbColumns].set_title(parameter)
      tabAx[int(idx/nbColumns), idx%nbColumns].boxplot(concatenatedValues)
      tabAx[int(idx/nbColumns), idx%nbColumns].set_xticklabels(labels)
  plt.savefig(os.path.join(outputFolderResult, 'globalParametersInsideCategories.png'))



from zebrazoom.extractZZParametersFromTailAngle import extractZZParametersFromTailAngle
from zebrazoom.dataAnalysis.datasetcreation.createDataFrame import createDataFrame
from zebrazoom.dataAnalysis.dataanalysis.populationComparaison import populationComparaison
from zebrazoom.dataAnalysis.dataanalysis.applyClustering import applyClustering



import numpy as np
import pandas as pd
import math
import os

def calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold(pathRootDirectory, experimentName, thresholdInDegrees):

  maxAmplitudeThreshold = thresholdInDegrees * (math.pi / 180)
  
  df = pd.read_excel(os.path.join(os.path.join(os.path.join(os.path.join(pathRootDirectory, 'dataAnalysis'), 'resultsKinematic'), experimentName), "globalParametersInsideCategories.xlsx"))
  
  outputFile = open(os.path.join(os.path.join(os.path.join(os.path.join(pathRootDirectory, 'dataAnalysis'), 'resultsKinematic'), experimentName), "numberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold.txt"), "w")
  print("There's a total of", len(df), "bouts in this dataset.")
  outputFile.write("There's a total of " + str(len(df)) + " bouts in this dataset.\n")

  allConditionsNames = np.unique(df['Condition'].tolist()).tolist()
  allGenotypesNames  = np.unique(df['Genotype'].tolist()).tolist()

  for conditionName in allConditionsNames:
    dfCond = df.loc[df['Condition'] == conditionName]
    for genotypeName in allGenotypesNames:
      dfCondGeno = dfCond.loc[dfCond['Genotype'] == genotypeName]
      nbTurns = np.sum(dfCondGeno['maxAmplitude'] > maxAmplitudeThreshold)
      nbSfs   = np.sum(dfCondGeno['maxAmplitude'] <= maxAmplitudeThreshold)
      nbBouts = len(dfCondGeno)
      print("For the condition:", conditionName, "and the genotype:", genotypeName, "there are:", nbSfs, "sfs and", nbTurns, "turns, for a total of", nbBouts, "bouts")
      outputFile.write("For the condition: " + conditionName + " and the genotype: " + genotypeName + " there are: " + str(nbSfs) + " sfs and " + str(nbTurns) + " turns, for a total of " + str(nbBouts) + " bouts\n")
  
  outputFile.close()



from createDataFrame import createDataFrame

dataframeOptions = {
  'pathToExcelFile'          : './experimentOrganizationExcel/',
  'fileExtension'            : '.xls',
  'resFolder'                : './data/',
  'nameOfFile'               : 'ctrlVsHomogenousPh',
  'smoothingFactorDynaParam' : 0,   # 0.001
  'nbFramesTakenIntoAccount' : 28
}

#####

dataframeOptions['nameOfFile'] = 'ctrlVsHomogenousPh'
dataframeOptions['nameOfFile'] = 'paramecia'
dataframeOptions['nameOfFile'] = 'pHCtrlVsParameciaCtrl'
dataframeOptions['nameOfFile'] = 'parameciaCtrlVsParameciaCtrl'
dataframeOptions['nameOfFile'] = 'parameciaSimple'

createDataFrame(pathToExcelFile, nameOfFile, fileExtension, smoothingFactorDynaParam, nbFramesTakenIntoAccount, resFolder)

#####

dataframeOptions['nameOfFile'] = 'ctrlVsSharpPh'
createDataFrame(pathToExcelFile, nameOfFile, fileExtension, smoothingFactorDynaParam, nbFramesTakenIntoAccount, resFolder)

dataframeOptions['nameOfFile'] = 'allCatamaran'
createDataFrame(pathToExcelFile, nameOfFile, fileExtension, smoothingFactorDynaParam, nbFramesTakenIntoAccount, resFolder)
